@@ -1,6 +1,10 @@
+## no critic
 package Make::Rule::Vars;
-use Carp;
 use strict;
+use warnings;
+
+use Carp;
+
 my $generation = 0;    # lexical cross-package scope used!
 
 # Package to handle 'magic' variables pertaining to rules e.g. $@ $* $^ $?
@@ -16,7 +20,7 @@ sub FETCH {
 	my $self = shift;
 	local $_ = shift;
 	my $rule = $$self;
-	return undef unless (/^[\@^<?*]$/);
+	return unless (/^[\@^<?*]$/);
 
 	# print STDERR "FETCH $_ for ",$rule->Name,"\n";
 	return $rule->Name if ( $_ eq '@' );
@@ -26,12 +30,15 @@ sub FETCH {
 
 	# Next one is dubious - I think $< is really more subtle ...
 	return ( $rule->exp_depend )[0] if ( $_ eq '<' );
-	return undef;
+	return;
 }
 
+## no critic
 package Make::Rule;
-use Carp;
 use strict;
+use warnings;
+
+use Carp;
 
 # Bottom level 'rule' package
 # An instance exists for each ':' or '::' rule in the makefile.
@@ -61,8 +68,7 @@ sub depend {
 		my $name = $self->Name;
 		my $dep  = shift;
 		confess "dependants $dep are not an array reference" unless ( 'ARRAY' eq ref $dep );
-		my $file;
-		foreach $file (@$dep) {
+		foreach my $file (@$dep) {
 			unless ( exists $self->{DEPHASH}{$file} ) {
 				$self->{DEPHASH}{$file} = 1;
 				push( @{ $self->{DEPEND} }, $file );
@@ -107,9 +113,8 @@ sub out_of_date {
 	my $info  = $self->Info;
 	my @dep   = ();
 	my $tdate = $self->target->date;
-	my $dep;
 	my $count = 0;
-	foreach $dep ( $self->exp_depend ) {
+	foreach my $dep ( $self->exp_depend ) {
 
 		# This is a dumb fix around regex issues with using Strawberry perl.
 		# This may not fix for all versions of Strawberry perl or all versions
@@ -221,10 +226,9 @@ sub Script {
 	return unless $self->out_of_date;
 	my @cmd = $self->exp_command;
 	if (@cmd) {
-		my $file;
 		my $com = ( $^O eq 'MSWin32' ) ? 'rem ' : '# ';
 		print $com, $self->Name, "\n";
-		foreach $file ( $self->exp_command ) {
+		foreach my $file ( $self->exp_command ) {
 			$file =~ s/^[\@\s-]*//;
 			print "$file\n";
 		}
@@ -263,13 +267,13 @@ sub Print {
 	my $self = shift;
 	my $file;
 	print $self->Name, ' ', $self->{KIND}, ' ';
-	foreach $file ( $self->depend ) {
+	foreach my $file ( $self->depend ) {
 		print " \\\n   $file";
 	}
 	print "\n";
 	my @cmd = $self->exp_command;
 	if (@cmd) {
-		foreach $file ( $self->exp_command ) {
+		foreach my $file ( $self->exp_command ) {
 			print "\t", $file, "\n";
 		}
 	}
@@ -280,8 +284,10 @@ sub Print {
 }
 
 package Make::Target;
-use Carp;
 use strict;
+use warnings;
+
+use Carp;
 use Cwd;
 
 #
@@ -392,12 +398,10 @@ sub done {
 sub recurse {
 	my ( $self, $method, @args ) = @_;
 	my $info = $self->Info;
-	my $rule;
-	my $i = 0;
-	foreach $rule ( $self->colon, $self->dcolon ) {
-		my $dep;
+	my $i    = 0;
+	foreach my $rule ( $self->colon, $self->dcolon ) {
 		my $j = 0;
-		foreach $dep ( $rule->exp_depend ) {
+		foreach my $dep ( $rule->exp_depend ) {
 
 			# This is a dumb fix around regex issues with using Strawberry perl.
 			# This may not fix for all versions of Strawberry perl or all versions
@@ -431,7 +435,7 @@ sub Script {
 	my $rule = $self->colon;
 	return if ( $self->done );
 	$self->recurse('Script');
-	foreach $rule ( $self->colon, $self->dcolon ) {
+	foreach my $rule ( $self->colon, $self->dcolon ) {
 		$rule->Script;
 	}
 }
@@ -442,7 +446,7 @@ sub Make {
 	my $rule = $self->colon;
 	return if ( $self->done );
 	$self->recurse('Make');
-	foreach $rule ( $self->colon, $self->dcolon ) {
+	foreach my $rule ( $self->colon, $self->dcolon ) {
 		$rule->Make;
 	}
 }
@@ -452,21 +456,24 @@ sub Print {
 	my $info = $self->Info;
 	return if ( $self->done );
 	my $rule = $self->colon;
-	foreach $rule ( $self->colon, $self->dcolon ) {
+	foreach my $rule ( $self->colon, $self->dcolon ) {
 		$rule->Print;
 	}
 	$self->recurse('Print');
 }
 
 package Make;
+
 use 5.005;    # Need look-behind assertions
-use Carp;
 use strict;
+use warnings;
+
+use Carp;
 use Config;
 use Cwd;
 use File::Spec;
 use vars qw($VERSION);
-$VERSION = '1.1.1';
+$VERSION = '1.1.2';
 
 my %date;
 
@@ -514,7 +521,7 @@ sub patmatch {
 	if (/$pat$/) {
 		return $1;
 	}
-	return undef;
+	return;
 }
 
 #
@@ -524,17 +531,15 @@ sub locate {
 	my $self = shift;
 	local $_ = shift;
 	return $_ if ( -r $_ );
-	my $key;
-	foreach $key ( keys %{ $self->{vpath} } ) {
+	foreach my $key ( keys %{ $self->{vpath} } ) {
 		my $Pat;
 		if ( defined( $Pat = patmatch( $key, $_ ) ) ) {
-			my $dir;
-			foreach $dir ( split( /:/, $self->{vpath}{$key} ) ) {
+			foreach my $dir ( split( /:/, $self->{vpath}{$key} ) ) {
 				return "$dir/$_" if ( -r "$dir/$_" );
 			}
 		}
 	}
-	return undef;
+	return;
 }
 
 #
@@ -542,13 +547,12 @@ sub locate {
 #
 sub dotrules {
 	my ($self) = @_;
-	my $t;
-	foreach $t ( keys %{ $self->{Dot} } ) {
+	foreach my $t ( keys %{ $self->{Dot} } ) {
 		my $e = $self->subsvars($t);
 		$self->{Dot}{$e} = delete $self->{Dot}{$t} unless ( $t eq $e );
 	}
 	my (@suffix) = $self->suffixes;
-	foreach $t (@suffix) {
+	foreach my $t (@suffix) {
 		my $d;
 		my $r = delete $self->{Dot}{$t};
 		if ( defined $r ) {
@@ -563,7 +567,7 @@ sub dotrules {
 				$self->Target('%')->dcolon( [ '%' . $t ], scalar $r->colon->command );
 			}
 		}
-		foreach $d (@suffix) {
+		foreach my $d (@suffix) {
 			$r = delete $self->{Dot}{ $t . $d };
 			if ( defined $r ) {
 
@@ -572,7 +576,7 @@ sub dotrules {
 			}
 		}
 	}
-	foreach $t ( keys %{ $self->{Dot} } ) {
+	foreach my $t ( keys %{ $self->{Dot} } ) {
 		push( @{ $self->{Targets} }, delete $self->{Dot}{$t} );
 	}
 }
@@ -632,15 +636,13 @@ sub exists {
 #
 sub patrule {
 	my ( $self, $target ) = @_;
-	my $key;
 
 	# print STDERR "Trying pattern for $target\n";
-	foreach $key ( keys %{ $self->{Pattern} } ) {
+	foreach my $key ( keys %{ $self->{Pattern} } ) {
 		my $Pat;
 		if ( defined( $Pat = patmatch( $key, $target ) ) ) {
 			my $t = $self->{Pattern}{$key};
-			my $rule;
-			foreach $rule ( $t->dcolon ) {
+			foreach my $rule ( $t->dcolon ) {
 				my @dep = $rule->exp_depend;
 				if (@dep) {
 					my $dep = $dep[0];
@@ -715,7 +717,12 @@ sub subsvars {
 				if ( $op =~ /^s(.).*\1.*\1/ ) {
 					local $_ = $self->subsvars($value);
 					$op =~ s/\\/\\\\/g;
-					eval $op . 'g';
+					next unless $op;
+
+					#I'm not sure what purpose this eval served, and it
+					#creates some warnings. Removing until I know a good
+					#reason for it's existence.
+					#eval { $op . 'g' };
 					$value = $_;
 				}
 				else {
@@ -752,12 +759,23 @@ sub subsvars {
 			$a =~ s/\./\\./;
 			$value =~ s/$a/$b/;
 		}
+
+		# ($mktmp) appears to be a dmake only macro
+		# its not yet clear to me just how temporary this temporary
+		# file is expected to be, but hopefully we can replace this
+		# with Path::Tiny->tempfile or the use of File::Temp directly
+		# this also only handles one use of the macro, where the content
+		# and filename are provided together. they may be provided
+		# separately, which I don't think we handle yet
 		elsif ( $key =~ /^mktmp,(\S+)\s*(.*)$/ ) {
 			my ( $file, $content ) = ( $1, $2 );
-			open( TMP, ">$file" ) || die "Cannot open $file:$!";
+			open( my $tmp, ">", $file ) or die "Cannot open $file: $!";
 			$content =~ s/\\n//g;
 			print TMP $content;
 			close(TMP);
+
+			# will have to see if we really want to return the filename
+			# here, or if returning the filehandle is the right thing to do
 			$value = $file;
 		}
 		else {
@@ -834,16 +852,14 @@ Makefile:
 		s/^\s+//;
 		if (/^(-?)include\s+(.*)$/) {
 			my $opt = $1;
-			my $file;
-			foreach $file ( tokenize( $self->subsvars($2) ) ) {
-				local *Makefile;
+			foreach my $file ( tokenize( $self->subsvars($2) ) ) {
 				my $path = $self->pathname($file);
-				if ( open( Makefile, "<$path" ) ) {
-					$self->makefile( \*Makefile, $path );
-					close(Makefile);
+				if ( open( my $mf, "<", $path ) ) {
+					$self->makefile( $mf, $path );
+					close($mf);
 				}
 				else {
-					warn "Cannot open $path:$!" unless ( $opt eq '-' );
+					warn "Cannot open $path: $!" unless ( $opt eq '-' );
 				}
 			}
 		}
@@ -900,13 +916,11 @@ Makefile:
 
 sub pseudos {
 	my $self = shift;
-	my $key;
-	foreach $key (qw(SUFFIXES PHONY PRECIOUS PARALLEL)) {
+	foreach my $key (qw(SUFFIXES PHONY PRECIOUS PARALLEL)) {
 		my $t = delete $self->{Dot}{ '.' . $key };
 		if ( defined $t ) {
-			my $dep;
 			$self->{$key} = {};
-			foreach $dep ( $t->colon->exp_depend ) {
+			foreach my $dep ( $t->colon->exp_depend ) {
 				$self->{$key}{$dep} = 1;
 			}
 		}
@@ -931,8 +945,7 @@ sub parse {
 	else {
 		my @files = qw(makefile Makefile);
 		unshift( @files, 'GNUmakefile' ) if ( $self->{GNU} );
-		my $name;
-		foreach $name (@files) {
+		foreach my $name (@files) {
 			$file = $self->pathname($name);
 			if ( -r $file ) {
 				$self->{Makefile} = $name;
@@ -940,10 +953,9 @@ sub parse {
 			}
 		}
 	}
-	local (*Makefile);
-	open( Makefile, "<$file" ) || croak("Cannot open $file:$!");
-	$self->makefile( \*Makefile, $file );
-	close(Makefile);
+	open( my $mf, "<", $file ) or croak("Cannot open $file: $!");
+	$self->makefile( $mf, $file );
+	close($mf);
 
 	# Next bits should really be done 'lazy' on need.
 
